==> edusoho-7.2.9.tar.gz: edusoho/api/config/container.php <==
<?php

$resources = array(
    'Article',
    'ArticleCategories',
    'Articles',
    'Classroom',
    'ClassroomMembers',
    'Classroom/Member',
    'Classroom/Members',
    'Classrooms',
    'ClassroomStatus',
    'ClassroomStatuses',
    'Course/Member',
    'Course/Members',
    'CourseMembers',
    'CourseMembership',
    'Course/Note',
    'Course/Notes',
    'Course/Lesson',
    'Course/Lessons',
    'Course/LessonsToBeDelete',
    'CourseReviews',
    'LessonLiveTickets',
    'LessonLiveTicket',
    'LessonReplay',
    'Exercise',
    'ExerciseResult',
    'MeChatroomes',
    'MeCourses',
    'User',
    'Users',
    'Course',
    'Courses',
    'Thread',
    'Threads',
    'ChaosThreads',
    'ChaosThreadsPosts',
    'Apps',
    'App',
    'Analysis',
    'Homework',
    'HomeworkResult',
    'HomeworkManager',
    'ThreadManager',
    'Thread',
    'Upload',
    'Status',
    'DiscoveryColumn',
    'Playlist',
    'IM/MeLogin',
    'IM/Conversations',
    'CourseThread',
    'CourseThreads',
    'CourseThreadPost',
    'CourseThreadPosts',
    'ClassRoomPlay',
    'ClassRoomPlayStatus',
    'ClassRoomThread',
    'ClassRoomThreads',
    'ThreadPosts',
    'ThreadPost',
    'Setting',
    'OpenCourse',
    'OpenCourses',
    'OpenCourse/Lesson',
    'OpenCourse/Lessons',
    'IM/MePush',
    'IM/Member',
    'IM/MemberSync'
);

foreach ($resources as $res) {
    $app["res.{$res}"] = $app->share(function () use ($res) {
        $class    = "Topxia\\Api\\Resource";
        $segments = explode('/', $res);
        foreach ($segments as $seg) {
            $class .= "\\{$seg}";
        }

        return new $class();
    });
}

==> edusoho-7.5.12.tar.gz: edusoho/api/config/container.php <==
<?php

$resources = array(
    'Article',
    'ArticleCategories',
    'Articles',
    'Classroom',
    'ClassroomMembers',
    'Classroom/Member',
    'Classroom/Members',
    'Classrooms',
    'ClassroomStatus',
    'ClassroomStatuses',
    'Course/Member',
    'Course/Members',
    'CourseMembers',
    'CourseMembership',
    'Course/Note',
    'Course/Notes',
    'Course/Lesson',
    'Course/Lessons',
    'Course/LessonsToBeDelete',
    'CourseReviews',
    'LessonLiveTickets',
    'LessonLiveTicket',
    'LessonReplay',
    'Exercise',
    'ExerciseResult',
    'MeChatroomes',
    'MeCourses',
    'User',
    'Users',
    'Course',
    'Courses',
    'Thread',
    'Threads',
    'ChaosThreads',
    'ChaosThreadsPosts',
    'Apps',
    'App',
    'Analysis',
    'Homework',
    'HomeworkResult',
    'HomeworkManager',
    'ThreadManager',
    'Thread',
    'Upload',
    'Status',
    'DiscoveryColumn',
    'Playlist',
    'IM/MeLogin',
    'IM/Conversations',
    'CourseThread',
    'CourseThreads',
    'CourseThreadPost',
    'CourseThreadPosts',
    'ClassRoomPlay',
    'ClassRoomPlayStatus',
    'ClassRoomThread',
    'ClassRoomThreads',
    'ThreadPosts',
    'ThreadPost',
    'Setting',
    'OpenCourse',
    'OpenCourses',
    'OpenCourse/Lesson',
    'OpenCourse/Lessons',
    'IM/MePush',
    'IM/Member',
    'IM/MemberSync',
    'Emails',
    'User/Password',
    'SmsCodes',
    'User/VerifiedMobile',
    'MyLearning',
    'CoursesLearnProgress',
    'LessonWatchTime'
);

foreach ($resources as $res) {
    $app["res.{$res}"] = function () use ($res) {
        $class    = "Topxia\\Api\\Resource";
        $segments = explode('/', $res);
        foreach ($segments as $seg) {
            $class .= "\\{$seg}";
        }

        return new $class();
    };
}
